export interface BaseClientConfig {
    token: string;
    businessAccountId: string;
    apiUrl?: string;
    onError?: (error: unknown) => void;
}
export interface MessageResponse {
    messaging_product: string;
    contacts: Array<{
        input: string;
        wa_id: string;
    }>;
    messages: Array<{
        id: string;
    }>;
}
export interface MediaResponse {
    id: string;
    url: string;
}
export interface UploadMediaResponse {
    id: string;
}
/**
 * Configuration for MessageTemplate-related operations.
 */
export interface MessageTemplateConfig extends BaseClientConfig {
    namespace: string;
}
/**
 * Represents a single message template.
 */
export interface MessageTemplate {
    id: string;
    name: string;
    language: string;
    category: string;
    components: Array<MessageTemplateComponent>;
    status: 'APPROVED' | 'PENDING' | 'REJECTED';
    created_time: string;
}
/**
 * Represents a component of a message template.
 */
export interface MessageTemplateComponent {
    type: 'HEADER' | 'BODY' | 'FOOTER' | 'BUTTONS';
    text?: string;
    buttons?: Array<MessageTemplateButton>;
    format?: 'TEXT' | 'IMAGE' | 'VIDEO' | 'DOCUMENT';
    example: any;
}
/**
 * Represents a button in a message template.
 */
export interface MessageTemplateButton {
    type: 'QUICK_REPLY' | 'URL';
    text: string;
    url?: string;
    payload?: string;
}
/**
 * Response when retrieving message templates.
 */
export interface GetMessageTemplatesResponse {
    data: Array<MessageTemplate>;
    paging?: {
        cursors: {
            before: string;
            after: string;
        };
    };
}
/**
 * Response when creating a message template.
 */
export interface CreateMessageTemplateResponse {
    id: string;
}
/**
 * Request payload for creating a message template.
 */
export interface CreateMessageTemplateRequest {
    name: string;
    language: string;
    category: string;
    components: Array<MessageTemplateComponent>;
}
/**
 * Response when deleting a message template.
 */
export interface DeleteMessageTemplateResponse {
    success: boolean;
}
/**
 * Interface for the MessageTemplate module.
 */
export interface MessageTemplateModule {
    /**
     * Fetches all message templates associated with the account.
     */
    getMessageTemplates(): Promise<GetMessageTemplatesResponse>;
    /**
     * Creates a new message template.
     */
    createMessageTemplate(template: CreateMessageTemplateRequest): Promise<CreateMessageTemplateResponse>;
    /**
     * Deletes a message template by ID.
     */
    deleteMessageTemplate(templateId: string): Promise<DeleteMessageTemplateResponse>;
}
